@@ -1,3 +1,14 @@
+#
+# Release Gym Environments
+#
+
+from .baby_robot_v0 import BabyRobot_v0
+
+
+#
+# Example Gym Environments
+#
+
 from .baby_robot_env_v0 import BabyRobotEnv_v0
 from .baby_robot_env_v1 import BabyRobotEnv_v1
 from .baby_robot_env_v2 import BabyRobotEnv_v2
@@ -6,3 +17,5 @@ from .baby_robot_env_v4 import BabyRobotEnv_v4
 from .baby_robot_env_v5 import BabyRobotEnv_v5
 from .baby_robot_env_v6 import BabyRobotEnv_v6
 from .baby_robot_env_v7 import BabyRobotEnv_v7
+
+
